==> kebook2-0.1.1r1.tar.bz2: kebook2-0.1.1r1/kebook2/main.cpp <==
/*
 * $Id: main.cpp,v 1.2 2000/12/23 14:51:36 hige Exp $
 *
 * Copyright (C) 1999 SUZUKI, Mitsuhiro <hige@higesoft.rim.or.jp>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */
#include <kapp.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <iostream>

#include "kebook.h"
#include "cebook.hpp"

static const char* description =
        I18N_NOOP("KEBook2");
// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
        
static KCmdLineOptions options[] =
{
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};

int main(int argc, char* argv[])
{
    KAboutData aboutData(PACKAGE, I18N_NOOP("kebook2"),
                         VERSION, description, KAboutData::License_GPL,
                         "(c) 2000, SUZUKI, Mitsuhiro");
    aboutData.addAuthor("SUZUKI, Mitsuhiro", 0, "hige@higesoft.rim.or.jp");
    KCmdLineArgs::init(argc, argv, &aboutData);
    KCmdLineArgs::addCmdLineOptions(options); 
  
    KEBookApp* app = new KEBookApp();
    int rc = app->getCurrentError().getErrorCode();
    if (rc == EB_NO_ERR) {
        // All session management is handled in the RESTORE macro
        if (app->isRestored()) {
                RESTORE(KEBook)
        } else {
            KEBook* widget = new KEBook();
            app->setMainWidget(widget);
            widget->show();
        }
    } else {
        cerr << app->getCurrentError().what() << endl;
        delete app;
        return rc;
    }
    rc = app->exec();
    delete app;
	return rc;
}

==> kebook2-0.2b.tar.bz2: kebook2-0.2b/kebook2/main.cpp <==
/*
 * $Id: main.cpp,v 1.2.2.1 2001/04/14 22:45:10 hige Exp $
 *
 * Copyright (C) 1999 SUZUKI, Mitsuhiro <hige@higesoft.rim.or.jp>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */
#include <kapp.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <iostream>

#include "kebook.h"
#include "cebook.hpp"

using namespace ebook;

static const char* description =
        I18N_NOOP("KEBook2");
// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
        
static KCmdLineOptions options[] =
{
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};

int main(int argc, char* argv[])
{
    KAboutData aboutData(PACKAGE, I18N_NOOP("kebook2"),
                         VERSION, description, KAboutData::License_GPL,
                         "(c) 2000, SUZUKI, Mitsuhiro");
    aboutData.addAuthor("SUZUKI, Mitsuhiro", 0, "hige@higesoft.rim.or.jp");
    KCmdLineArgs::init(argc, argv, &aboutData);
    KCmdLineArgs::addCmdLineOptions(options);
    
    // Initialize EB Library
    CEBookError eberror = CEBook::initialize();
    if (eberror.getErrorCode() != EB_SUCCESS) {
        cerr << eberror.what() << endl;
        return eberror.getErrorCode();
    }
    
    KEBookApp* app = new KEBookApp();
    EB_Error_Code rc = app->getCurrentError().getErrorCode();
    if (rc == EB_SUCCESS) {
        // All session management is handled in the RESTORE macro
        if (app->isRestored()) {
                RESTORE(KEBook)
        } else {
            KEBook* widget = new KEBook();
            app->setMainWidget(widget);
            widget->show();
        }
    } else {
        cerr << rc << ":" << app->getCurrentError().what() << endl;
        delete app;
        CEBook::finalize();
        return rc;
    }
    rc = app->exec();
    delete app;

    //Finalize EB Library
    CEBook::finalize();
    
	return rc;
}
